@@ -11,9 +11,11 @@
 #'\dontrun{funnel_plot(theme=funnel_clean())}
 funnel_clean <- function(){
   theme_minimal() %+replace% 
-  theme(legend.position = "bottom",
-        plot.title = element_text(hjust = 0.5, face = "bold"),
-        plot.subtitle = element_text(hjust = 0.5, face = "italic"))
+  theme(legend.position = "bottom"
+        ,legend.text = element_text(size = 8)
+        ,legend.title = element_text(size = 8)
+        ,plot.title = element_text(size = 14, hjust = 0.5, face = "bold")
+        ,plot.subtitle = element_text(size=10, hjust = 0.5, face = "italic"))
 }
 
 
@@ -30,7 +32,9 @@ funnel_clean <- function(){
 #' \dontrun{funnel_plot(theme=funnel_grey())}
 funnel_grey <- function(){
   theme_grey() %+replace% 
-    theme(legend.position = "bottom",
-          plot.title = element_text(hjust = 0.5, face = "bold"),
-          plot.subtitle = element_text(hjust = 0.5, face = "italic"))
+    theme(legend.position = "bottom"
+          ,legend.text = element_text(size = 8)
+          ,legend.title = element_text(size = 8)
+          ,plot.title = element_text(size = 14, hjust = 0.5, face = "bold")
+          ,plot.subtitle = element_text(size=10, hjust = 0.5, face = "italic"))
 }
